sole_root_package

Function sole_root_package 

pub fn sole_root_package(
    metadata: &[u8],
    root_manifest: &Path,
) -> Option<String>
The manifest path of the one selected default package rooted at the target, or None for every other workspace shape.