Module stage

Module stage 

Arguments for rk stage.

Structs

StageArgs
Write the candidate this binary would land in a target into a disposable stage, beside the knowledge that explains it.

Enums

StageAction
The stage subcommands.