pub struct Artifact {
pub path: String,
pub sha256: Digest,
}Expand description
One embedded file and the digest of its bytes.
Fields
path: StringThe artifact’s path, carrying its payload root as the first segment.
sha256: DigestSHA-256 of the embedded bytes.