run

Function run 

pub fn run(args: &UpgradeArgs) -> Result<(), RkError>
Upgrade the landed target to this binary’s payload.

Errors

Returns a refusal for a missing record, an unknown record schema, a record from a newer binary, a rendered destination that is not a regular file, and — on apply — any collected conflict; and RkError::Io on filesystem failure.