flake_ref

Function flake_ref 

pub fn flake_ref(
    host: Option<&str>,
    owner_repo: Option<&str>,
    tag: &str,
) -> Option<String>
The flake reference for a forge host and path at a tag, where the host has a flake reference type: github: and gitlab:.