pub fn observe(path: &Utf8Path) -> Result<Source, RkError>Expand description
Read the source, offline.
Errors
Returns RkError::Missing for a path that is not a directory and
RkError::Io where a present file does not read.
pub fn observe(path: &Utf8Path) -> Result<Source, RkError>Read the source, offline.
Returns RkError::Missing for a path that is not a directory and
RkError::Io where a present file does not read.