pub fn observe(target: &Utf8Path) -> Result<Observed, RkError>Expand description
Read a target’s devshell wiring, offline.
Errors
Returns RkError::Missing for a target that is not a directory and
RkError::Io where a present file does not read.
pub fn observe(target: &Utf8Path) -> Result<Observed, RkError>Read a target’s devshell wiring, offline.
Returns RkError::Missing for a target that is not a directory and
RkError::Io where a present file does not read.