pub const fn trunk_state(
level: bool,
local_reaches_remote: bool,
remote_reaches_local: bool,
) -> TrunkStateExpand description
Where the local trunk stands against the remote tip, if any.
pub const fn trunk_state(
level: bool,
local_reaches_remote: bool,
remote_reaches_local: bool,
) -> TrunkStateWhere the local trunk stands against the remote tip, if any.