routing_block

Function routing_block 

pub fn routing_block(
    source: &dyn ReleaseSource,
    workflow: Workflow,
) -> Result<String, RkError>
The routing block for one workflow mode, read from the bundle source carries and composed by pure::compose_routing.

Errors

Returns the source’s failures for a bundle that does not carry the block.