gate

Function gate 

pub fn gate(plan: &Plan) -> Result<(), RkError>
Refuse anything but a ready plan.

Errors

A refusal with Reason::PlanNotReady naming the unresolved decision ids for a plan that needs a decision, or the failed required preconditions for a blocked one.