pub const fn classify(
record: RecordState,
verdict: Verdict,
owned_drift: bool,
) -> ClassificationExpand description
Derive the classification from the record’s state, the verdict, and whether the comparison found owned drift.
pub const fn classify(
record: RecordState,
verdict: Verdict,
owned_drift: bool,
) -> ClassificationDerive the classification from the record’s state, the verdict, and whether the comparison found owned drift.