pub fn verdict(facts: &RepositoryFacts) -> VerdictExpand description
Compute the verdict from the facts. Pure, so the rule is testable without a repository.
pub fn verdict(facts: &RepositoryFacts) -> VerdictCompute the verdict from the facts. Pure, so the rule is testable without a repository.