pub struct Selected {
pub guidance: Guidance,
pub precondition: Option<Precondition>,
pub decision: Option<Decision>,
}Expand description
What the selection produces.
Fields
guidance: GuidanceThe section, for the plan.
precondition: Option<Precondition>The coverage precondition, where coverage is a condition at all.
decision: Option<Decision>The decision partial coverage asks, where it asks one.