pub struct ReleaseIntent {
pub mode: ReleaseMode,
pub driver: Option<String>,
pub style: Option<Style>,
pub line_prefix: Option<String>,
}Expand description
The release intent: the mode and, for an automatic release, its driver, style, and line prefix.
SATISFIES project-profile:release-intent-has-three-modes
Fields
mode: ReleaseModeThe mode.
driver: Option<String>The technology that states the version and takes the bot; present for an automatic release alone.
style: Option<Style>The release style; present for an automatic release alone.
line_prefix: Option<String>The release-line branch prefix; present for an automatic release alone.