pub fn embedded_block(path: &str) -> Result<&'static str, RkError>Expand description
One authored block this binary embeds, as text, by its embedded path.
Errors
RkError::Other for a block this binary does not embed or one that
is not UTF-8, both defects in the binary.