hooks_block

Function hooks_block 

pub fn hooks_block(
    mode: CheckoutMode,
    integration: Integration,
) -> Result<String, RkError>
The hook block for one checkout mode, from this binary’s embedded templates.

Errors

A block this binary does not embed, a defect in the binary.