pub fn hooks_marker_defect(text: &str) -> Option<String>Expand description
marker_defect for the hook file, the destination whose entries
execute.
pub fn hooks_marker_defect(text: &str) -> Option<String>marker_defect for the hook file, the destination whose entries
execute.