routing_block

Function routing_block 

pub fn routing_block(
    mode: CheckoutMode,
    integration: Integration,
) -> Result<String, RkError>
The routing block for one checkout mode, from this binary’s embedded templates.

Errors

A block this binary does not embed, a defect in the binary.