pub fn parse_compatibility(text: &str) -> Result<Compatibility, RkError>Expand description
Parse the compatibility file’s text.
Errors
Returns RkError::Other where the text is not the declared shape.
pub fn parse_compatibility(text: &str) -> Result<Compatibility, RkError>Parse the compatibility file’s text.
Returns RkError::Other where the text is not the declared shape.