pub fn check_schema(schema: u32, version: &str) -> Result<(), RkError>Expand description
The protocol rule, as one function both sides of the boundary test.
Errors
Returns RkError::Refusal when schema exceeds PAYLOAD_SCHEMA.
pub fn check_schema(schema: u32, version: &str) -> Result<(), RkError>The protocol rule, as one function both sides of the boundary test.
Returns RkError::Refusal when schema exceeds PAYLOAD_SCHEMA.