pub enum Manager {
Flake,
Mise,
Asdf,
Devbox,
}Expand description
A tool manager a project declares its development tools through.
Variants
Flake
A Nix flake: an input pinned at a tag and its package in the devshell.
Mise
mise: one [tools] entry in its configuration file.
Asdf
asdf: one line in .tool-versions.
Devbox
devbox: one entry in the packages array of devbox.json.
Implementations
Sourceimpl Manager
impl Manager
Sourcepub const fn default_file(self) -> &'static str
pub const fn default_file(self) -> &'static str
The default file a manager is seeded into when absent.
Sourcepub const fn candidates(self) -> &'static [&'static str]
pub const fn candidates(self) -> &'static [&'static str]
The paths a manager declares itself at, in precedence order.