pub fn read_gate(target: &Utf8Path, required_check: &str) -> GateReportExpand description
Read every workflow under the target’s .github/workflows and judge
the named check against the jobs that report on a pull request.
pub fn read_gate(target: &Utf8Path, required_check: &str) -> GateReportRead every workflow under the target’s .github/workflows and judge
the named check against the jobs that report on a pull request.