pub struct Listing(/* private fields */);Expand description
The paths one package ships, one per listed line.
Implementations
Sourceimpl Listing
impl Listing
Sourcepub fn parse(stdout: &[u8]) -> Self
pub fn parse(stdout: &[u8]) -> Self
Parse cargo package --list output: trimmed, non-empty lines.
Sourcepub fn carries(&self, path: &str) -> bool
pub fn carries(&self, path: &str) -> bool
Whether the package ships exactly path. An exact line, never a
substring: docs/SECURITY.md and SECURITY.md.bak are different
files.
Sourcepub fn touched_by<'a>(&self, changed: impl IntoIterator<Item = &'a str>) -> bool
pub fn touched_by<'a>(&self, changed: impl IntoIterator<Item = &'a str>) -> bool
Whether any of changed is a path the package ships: the test
release-plz applies to attribute a commit to the package.