pub enum SetupAction {
Check {
target: Utf8PathBuf,
repo: Option<String>,
forge: Option<String>,
required_check: Option<String>,
json: bool,
},
Step {
name: String,
target: Utf8PathBuf,
repo: Option<String>,
forge: Option<String>,
required_check: Option<String>,
apply: bool,
json: bool,
},
Script {
name: String,
forge: Option<String>,
},
}Expand description
The setup subcommands.
Variants
Check
Prove the desired state against the forge, mutating nothing.
Fields

target: Utf8PathBufThe repository to check.
Step
Run one step by name, for recovery and rerun.
Fields

target: Utf8PathBufThe repository to set up.
Script
Print one embedded setup script, for audit.