pub fn run(args: &DevshellArgs) -> Result<(), RkError>Expand description
Dispatch the devshell action.
Errors
Returns RkError::Missing for a target that is not a directory,
RkError::Io where a present file does not read, and
RkError::Usage for an action this build does not carry yet.