resolve

Function resolve 

pub fn resolve(
    source: &Source,
    argument: Option<&str>,
) -> Result<Resolved, RkError>
Resolve the pin from the argument, else from the source tree.

Errors

Returns RkError::Usage for an argument that is not a version and for a source that declares none while no argument was given.