pub fn forge_for_host(host: &str) -> Option<Forge>
The forge a host maps to. gitlab.com and hosts that name gitlab map to GitLab; a self-hosted instance on a host name that says nothing needs --forge.
gitlab.com
--forge