pub fn hooks_block(
source: &dyn ReleaseSource,
workflow: Workflow,
) -> Result<String, RkError>Expand description
The hook block for one workflow mode, read from the bundle source
carries and composed by pure::compose_hooks.
Errors
Returns the source’s failures for a bundle that does not carry the block.