pair_files

Function pair_files 

pub fn pair_files(
    tech: &str,
    forge: &str,
) -> Result<Vec<(String, &'static [u8])>, RkError>
The landable files of one (technology, forge) pair, as (destination, payload bytes).

Errors

Returns RkError::Usage naming the known bindings for an unknown technology, and the supported pairs for a pair with no files.