pub fn render(manifest: &Manifest) -> Result<Vec<u8>, RkError>Expand description
The bytes [write] puts on disk for a record, so a planner can name
the digest of the record an apply writes before anything is written.
Errors
A serialization failure, which is a defect in this binary.