pub fn plan(inputs: Inputs<'_>) -> Result<Planned, RkError>
Compute the plan.
Returns the seam’s own failures where a bundle cannot be read, and a serialization failure for the planned record, which is a defect.