embedded_block

Function embedded_block 

pub fn embedded_block(path: &str) -> Result<&'static str, RkError>
One authored block this binary embeds, as text, by its payload path.

Errors

RkError::Other for a block this binary does not embed or one that is not UTF-8, both defects in the binary.