pub fn parse_guidance(
version: &str,
text: &str,
) -> Result<GuidanceFile, RkError>Expand description
Parse one guidance file.
Errors
Returns RkError::Other for a file without a heading, without the
two fields, with an action outside the closed set, or with an empty
destination list.